/*-
 * %%----------------------------------------------------------------------------------------------
 * Archive ouverte UNIGE - AoU Admin - MetadataValidatorV2Test.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2022 - 2023 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.aou.test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.mockito.Mockito.when;

import java.util.Optional;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.validation.BeanPropertyBindingResult;
import org.springframework.validation.BindingResult;

import ch.unige.aou.AouMetadataVersion;
import ch.unige.aou.model.publication.Publication;
import ch.unige.aou.model.rest.UnigePersonDTO;
import ch.unige.aou.model.xml.deposit.v2_4.DepositDoc;
import ch.unige.aou.service.metadata.MetadataExtractorV2;
import ch.unige.aou.service.metadata.MetadataValidatorV2;
import ch.unige.aou.service.rest.RockUnigePersonSearchService;

public class MetadataValidatorV2Test extends MetadataValidatorServiceTest {

  private MetadataValidatorV2 metadataValidator;
  private MetadataExtractorV2 metadataExtractor;
  @Mock
  private RockUnigePersonSearchService unigePersonSearchService;

  protected static final String CN_INDIVIDU = "12345";

  @Override
  @BeforeEach
  public void setUp() {
    super.setUp();
    this.metadataExtractor = new MetadataExtractorV2(this.aouProperties, this.publicationTypeService, this.publicationSubtypeService,
            this.publicationSubSubtypeService, this.structureService, this.researchGroupService, this.contributorService,
            this.labeledLanguageService, this.journalTitleRemoteService, this.personService, this.messageService, this.unigePersonSearchService);

    this.metadataValidator = new MetadataValidatorV2(this.aouProperties, this.metadataExtractor, this.messageService,
            this.publicationTypeService, this.publicationSubtypeService, this.publicationSubSubtypeService, this.researchGroupService,
            this.structureService, this.duplicateService, this.unigePersonSearchService, this.documentFileService, this.historyService);
  }

  @Test
  void validateRulesForValidatorsWithoutErrorsTest() {
    /**
     * Create DepositDoc from Json form
     */
    String jsonFormData = this.getJsonFormData(AouMetadataVersion.getDefaultVersion());

    DepositDoc depositDoc = this.metadataExtractor.createDepositDocFromJsonFormData(jsonFormData);

    Publication publication = new Publication();
    final BindingResult errors = new BeanPropertyBindingResult(publication, publication.getClass().getName());

    UnigePersonDTO unigePersonDTO = new UnigePersonDTO(CN_INDIVIDU, "John", "Doe", 1980, "author", "structure", null);
    when(this.unigePersonSearchService.searchByCnIndividu(CN_INDIVIDU)).thenReturn(Optional.of(unigePersonDTO));

    this.metadataValidator.validateRulesForValidators(publication, depositDoc, errors);
    assertEquals(errors.getAllErrors().size(), 0); // there no errors
  }

  @Test
  void validateRulesForValidatorsWithErrorsTest() {
    /**
     * Create DepositDoc from Json form
     */
    String jsonFormData = this.getJsonFormData(AouMetadataVersion.getDefaultVersion());

    DepositDoc depositDoc = this.metadataExtractor.createDepositDocFromJsonFormData(jsonFormData);

    Publication publication = new Publication();
    final BindingResult errors = new BeanPropertyBindingResult(publication, publication.getClass().getName());
    Pageable pageable = PageRequest.of(0, 10);

    UnigePersonDTO unigePersonDTO = new UnigePersonDTO(CN_INDIVIDU, "Unkonw", "Unkonw", 1980, "author", "structure", null);
    when(this.unigePersonSearchService.searchByCnIndividu(CN_INDIVIDU)).thenReturn(Optional.of(unigePersonDTO));

    this.metadataValidator.validateRulesForValidators(publication, depositDoc, errors);
    assertEquals(errors.getAllErrors().size(), 2); // there are errors
  }
}
